@@ -654,16 +654,30 @@ class TrackMeHandlerSplkMhmWrite_v2(trackme_rest_handler.RESTHandler):
                 collection.data.delete(json.dumps({"_key": key}))
 
                 if deletion_type == "permanent":
-                    # Register a new permanently deleted object
-                    collection_perm_deleted.data.insert(
-                        json.dumps(
-                            {
-                                "ctime": str(time.time()),
-                                "object": str(object_value),
-                                "object_category": "splk-mhm",
-                            }
-                        )
-                    )
+                    # Register a new permanently deleted object, if not already present
+                    try:
+                        record_perm_deleted = collection_perm_deleted.data.query(
+                            query=json.dumps({"object": object_value, "object_category": "splk-mhm"})
+                        )[0]
+                        pass
+                    except Exception as e:
+                        record_perm_deleted = None
+
+                    if not record_perm_deleted:
+                        try:
+                            collection_perm_deleted.data.insert(
+                                json.dumps(
+                                    {
+                                        "ctime": str(time.time()),
+                                        "object": str(object_value),
+                                        "object_category": "splk-mhm",
+                                    }
+                                )
+                            )
+                        except Exception as e:
+                            logger.error(
+                                f'tenant_id="{tenant_id}", failed to register a new permanently deleted object, object="{object_value}", exception="{str(e)}"'
+                            )
 
                 # Record an audit change
                 try:
@@ -989,6 +1003,267 @@ class TrackMeHandlerSplkMhmWrite_v2(trackme_rest_handler.RESTHandler):
         else:
             return {"payload": req_summary, "status": 500}
 
+    # Update monitoring time policy and rules by object name
+    def post_mh_update_monitoring_time(self, request_info, **kwargs):
+        # Retrieve from data
+        try:
+            resp_dict = json.loads(str(request_info.raw_args["payload"]))
+        except Exception as e:
+            resp_dict = None
+
+        if resp_dict is not None:
+            try:
+                describe = resp_dict["describe"]
+                if describe in ("true", "True"):
+                    describe = True
+            except Exception as e:
+                describe = False
+            if not describe:
+                tenant_id = resp_dict["tenant_id"]
+
+                # handle object_list / keys_list
+                object_list = resp_dict.get("object_list", None)
+                if object_list:
+                    if not isinstance(object_list, list):
+                        object_list = object_list.split(",")
+
+                keys_list = resp_dict.get("keys_list", None)
+                if keys_list:
+                    if not isinstance(keys_list, list):
+                        keys_list = keys_list.split(",")
+
+                if not object_list and not keys_list:
+                    return {
+                        "payload": {
+                            "error": "either object_list or keys_list must be provided"
+                        },
+                        "status": 500,
+                    }
+
+                # Get monitoring_time_policy (optional)
+                monitoring_time_policy = resp_dict.get("monitoring_time_policy", None)
+                
+                # Get monitoring_time_rules (optional, takes precedence over policy)
+                monitoring_time_rules = resp_dict.get("monitoring_time_rules", None)
+
+                # Validate that at least one is provided
+                if not monitoring_time_policy and not monitoring_time_rules:
+                    return {
+                        "payload": {
+                            "error": "either monitoring_time_policy or monitoring_time_rules must be provided"
+                        },
+                        "status": 500,
+                    }
+
+                # Validate monitoring_time_rules format if provided
+                if monitoring_time_rules is not None:
+                    if isinstance(monitoring_time_rules, str):
+                        try:
+                            monitoring_time_rules = json.loads(monitoring_time_rules)
+                        except Exception as e:
+                            return {
+                                "payload": {
+                                    "error": f"monitoring_time_rules must be a valid JSON object, error: {str(e)}"
+                                },
+                                "status": 500,
+                            }
+                    
+                    if not isinstance(monitoring_time_rules, dict):
+                        return {
+                            "payload": {
+                                "error": "monitoring_time_rules must be a dictionary with week day keys (0-6) and hour lists as values"
+                            },
+                            "status": 500,
+                        }
+                    
+                    # Validate each day entry
+                    for day_key, hours_list in monitoring_time_rules.items():
+                        try:
+                            day_int = int(day_key)
+                            if day_int < 0 or day_int > 6:
+                                return {
+                                    "payload": {
+                                        "error": f"monitoring_time_rules: day key must be 0-6 (Sunday-Saturday), got {day_int}"
+                                    },
+                                    "status": 500,
+                                }
+                        except (ValueError, TypeError):
+                            return {
+                                "payload": {
+                                    "error": f"monitoring_time_rules: day key must be an integer 0-6, got {day_key}"
+                                },
+                                "status": 500,
+                            }
+                        
+                        if not isinstance(hours_list, list):
+                            return {
+                                "payload": {
+                                    "error": f"monitoring_time_rules: hours for day {day_key} must be a list"
+                                },
+                                "status": 500,
+                            }
+                        
+                        # Validate hours (0-23, with optional decimals like 0.5, 0.25)
+                        for hour in hours_list:
+                            try:
+                                hour_float = float(hour)
+                                if hour_float < 0 or hour_float >= 24:
+                                    return {
+                                        "payload": {
+                                            "error": f"monitoring_time_rules: hours must be between 0-23.99, got {hour_float}"
+                                        },
+                                        "status": 500,
+                                    }
+                                # Check for valid decimal increments (0.25, 0.5, 0.75)
+                                if hour_float != int(hour_float):
+                                    decimal_part = hour_float - int(hour_float)
+                                    if decimal_part not in [0.25, 0.5, 0.75]:
+                                        return {
+                                            "payload": {
+                                                "error": f"monitoring_time_rules: decimal hours must be .25, .5, or .75, got {hour_float}"
+                                            },
+                                            "status": 500,
+                                        }
+                            except (ValueError, TypeError):
+                                return {
+                                    "payload": {
+                                        "error": f"monitoring_time_rules: hour value must be numeric, got {hour}"
+                                    },
+                                    "status": 500,
+                                }
+
+                # Validate monitoring_time_policy format if provided
+                if monitoring_time_policy is not None:
+                    valid_policies = [
+                        "all_time",
+                        "business_days_all_hours",
+                        "monday_saturday_all_hours",
+                        "business_days_08h_20h",
+                        "monday_saturday_08h_20h",
+                    ]
+                    
+                    # Check if it's a string/list of predefined rules
+                    if isinstance(monitoring_time_policy, str):
+                        if monitoring_time_policy not in valid_policies:
+                            # Try to parse as JSON (might be dictionary format)
+                            try:
+                                monitoring_time_policy = json.loads(monitoring_time_policy)
+                            except Exception:
+                                return {
+                                    "payload": {
+                                        "error": f"monitoring_time_policy must be one of {valid_policies} or a valid JSON dictionary"
+                                    },
+                                    "status": 500,
+                                }
+                    elif isinstance(monitoring_time_policy, list):
+                        # Validate all items in list are valid policies
+                        for policy in monitoring_time_policy:
+                            if policy not in valid_policies:
+                                return {
+                                    "payload": {
+                                        "error": f"monitoring_time_policy list contains invalid policy: {policy}, valid options are {valid_policies}"
+                                    },
+                                    "status": 500,
+                                }
+                    elif isinstance(monitoring_time_policy, dict):
+                        # Dictionary format is allowed (same as monitoring_time_rules)
+                        pass
+                    else:
+                        return {
+                            "payload": {
+                                "error": "monitoring_time_policy must be a string, list of strings, or dictionary"
+                            },
+                            "status": 500,
+                        }
+
+        else:
+            # body is required in this endpoint, if not submitted describe the usage
+            describe = True
+
+        if describe:
+            response = {
+                "describe": "This endpoint configures the monitoring time policy and rules for an existing metric host, it requires a POST call with the following information:",
+                "resource_desc": "Update monitoring time policy/rules for a comma separated list of entities",
+                "resource_spl_example": "| trackme url=\"/services/trackme/v2/splk_mhm/write/mh_update_monitoring_time\" mode=\"post\" body=\"{'tenant_id':'mytenant','object_list':'key:env|splunk','monitoring_time_policy':'business_days_08h_20h'}\"",
+                "options": [
+                    {
+                        "tenant_id": "The tenant identifier",
+                        "object_list": "List of object entities, provided as a comma separated list of fields, you can provid object_list or keys_list",
+                        "keys_list": "List of key entities, provided as a comma separated list of fields, you can provid object_list or keys_list",
+                        "monitoring_time_policy": "OPTIONAL: predefined policy name (all_time, business_days_all_hours, monday_saturday_all_hours, business_days_08h_20h, monday_saturday_08h_20h) or dictionary format like monitoring_time_rules",
+                        "monitoring_time_rules": "OPTIONAL: dictionary with week day keys (0-6 for Sunday-Saturday) and hour lists as values, e.g. {0: [8,9,10], 1: [8,9,10]}. Hours can be 0-23 or decimals like 0.5 (00:30), 0.25 (00:15), 0.75 (00:45). Takes precedence over monitoring_time_policy if both provided.",
+                        "update_comment": "OPTIONAL: a comment for the update, comments are added to the audit record, if unset will be defined to: API update",
+                    }
+                ],
+            }
+
+            return {"payload": response, "status": 200}
+
+        # Update comment is optional and used for audit changes
+        try:
+            update_comment = resp_dict["update_comment"]
+        except Exception as e:
+            update_comment = "API update"
+
+        # Get splunkd port
+        splunkd_port = request_info.server_rest_port
+
+        # Get service
+        service = client.connect(
+            owner="nobody",
+            app="trackme",
+            port=splunkd_port,
+            token=request_info.session_key,
+            timeout=600,
+        )
+
+        # set loglevel
+        loglevel = trackme_getloglevel(
+            request_info.system_authtoken, request_info.server_rest_port
+        )
+        logger.setLevel(loglevel)
+
+        # Data collection
+        collection_name = f"kv_trackme_mhm_tenant_{tenant_id}"
+        collection = service.kvstore[collection_name]
+
+        # Prepare the request_info with the necessary data
+        update_request_info = {
+            "tenant_id": tenant_id,
+            "component": "mhm",
+            "object_list": object_list,
+            "keys_list": keys_list,
+        }
+
+        # Prepare the update fields
+        # monitoring_time_rules takes precedence over monitoring_time_policy
+        update_fields = {}
+        if monitoring_time_rules is not None:
+            # Convert dict keys to strings if they're integers (for JSON serialization)
+            if isinstance(monitoring_time_rules, dict):
+                monitoring_time_rules = {str(k): v for k, v in monitoring_time_rules.items()}
+            update_fields["monitoring_time_rules"] = json.dumps(monitoring_time_rules) if isinstance(monitoring_time_rules, dict) else monitoring_time_rules
+        if monitoring_time_policy is not None:
+            if isinstance(monitoring_time_policy, dict):
+                monitoring_time_policy = {str(k): v for k, v in monitoring_time_policy.items()}
+            update_fields["monitoring_time_policy"] = json.dumps(monitoring_time_policy) if isinstance(monitoring_time_policy, (dict, list)) else monitoring_time_policy
+
+        # Call the generic update function
+        response, status_code = generic_batch_update(
+            self,
+            request_info,
+            update_request_info=update_request_info,
+            collection=collection,
+            update_fields=update_fields,
+            persistent_fields=persistent_fields_mhm,
+            component="mhm",
+            update_comment=update_comment,
+            audit_context="update monitoring time policy/rules",
+            audit_message="Monitoring time policy/rules were updated successfully",
+        )
+
+        return {"payload": response, "status": status_code}
+
     # Update SLA class
     def post_mh_update_sla_class(self, request_info, **kwargs):
         # Retrieve from data
