@@ -359,33 +359,6 @@ class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
         for key in user_theme_prefs:
             final_response[key] = user_theme_prefs.get(key)
 
-        # theme & user prefs
-        record_url = "%s/services/trackme/v2/configuration/vtenants_user_prefs" % (
-            request_info.server_rest_uri
-        )
-
-        # position
-        position_prefs = None
-        try:
-            response = requests.post(
-                record_url,
-                headers=header,
-                data=json.dumps({"target_user": username, "target_prefs": "position"}),
-                verify=False,
-                timeout=600,
-            )
-            if response.status_code == 200:
-                position_prefs = response.text
-                final_response["position_prefs"] = position_prefs
-        except Exception as e:
-            return {
-                "payload": {
-                    "response": f"An exception was encountered while retrieving the position preferences, exception={str(e)}",
-                    "exception": str(e),
-                },
-                "status": 500,
-            }
-
         # log perf only in debug
         logger.debug(
             f"function post_trackmeload has terminated, run_time={round(time.time() - start, 3)}"
@@ -544,33 +517,6 @@ class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
         for key in user_theme_prefs:
             final_response[key] = user_theme_prefs.get(key)
 
-        # theme & user prefs
-        record_url = "%s/services/trackme/v2/configuration/vtenants_user_prefs" % (
-            request_info.server_rest_uri
-        )
-
-        # position
-        position_prefs = None
-        try:
-            response = requests.post(
-                record_url,
-                headers=header,
-                data=json.dumps({"target_user": username, "target_prefs": "position"}),
-                verify=False,
-                timeout=600,
-            )
-            if response.status_code == 200:
-                position_prefs = response.text
-                final_response["position_prefs"] = position_prefs
-        except Exception as e:
-            return {
-                "payload": {
-                    "response": "An exception was encountered",
-                    "exception": str(e),
-                },
-                "status": 500,
-            }
-
         # active count
         trackmeload_response_tenants = final_response["tenants_json"].get("tenants", {})
 
@@ -1033,11 +979,11 @@ class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
 
                     # outliers_allowlist
                     outliers_allowlist = trackme_vtenant_conf[stanza.name].get(
-                        "mloutliers_allowlist", "dsm,dhm,flx,wlk,cim,fqm"
+                        "mloutliers_allowlist", "dsm,dhm,flx,wlk,fqm"
                     )
 
                     # Define the components
-                    outliers_components = ["dsm", "dhm", "flx", "wlk", "cim", "fqm"]
+                    outliers_components = ["dsm", "dhm", "flx", "wlk", "fqm"]
 
                     # Convert the allowlist to a set for faster lookups
                     mloutliers_set = set(outliers_allowlist.split(","))
@@ -1066,9 +1012,6 @@ class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
                     trackme_vtenant_conf[stanza.name]["mloutliers_wlk"] = (
                         mloutliers_dict["mloutliers_wlk"]
                     )
-                    trackme_vtenant_conf[stanza.name]["mloutliers_cim"] = (
-                        mloutliers_dict["mloutliers_cim"]
-                    )
 
             # response
             try:
