@@ -75,7 +75,8 @@ from trackme_rest_handler_alerting_user import (
 from trackme_rest_handler_alerting_admin import (
     TrackMeHandlerAlertingWriteOps_v2 as handler_alerting_admin,
 )
-from trackme_rest_handler_ack import TrackMeHandlerAck_v2 as handler_ack
+from trackme_rest_handler_ack_user import TrackMeHandlerAckReadOps_v2 as handler_ack_user
+from trackme_rest_handler_ack_power import TrackMeHandlerAckWriteOps_v2 as handler_ack_power
 from trackme_rest_handler_audit import TrackMeHandlerAudit_v2 as handler_audit
 from trackme_rest_handler_backup_and_restore import (
     TrackMeHandlerBackupAndRestore_v2 as handler_backup_and_restore,
@@ -95,15 +96,6 @@ from trackme_rest_handler_maintenance_kdb_user import (
 from trackme_rest_handler_maintenance_kdb_admin import (
     TrackMeHandlerMaintenanceKdbAdmin_v2 as handler_maintenance_kdb_admin,
 )
-from trackme_rest_handler_splk_cim_user import (
-    TrackMeHandlerSplkCimTrackingRead_v2 as handler_splk_cim_user,
-)
-from trackme_rest_handler_splk_cim_power import (
-    TrackMeHandlerSplkCimTrackingWrite_v2 as handler_splk_cim_power,
-)
-from trackme_rest_handler_splk_cim_admin import (
-    TrackMeHandlerSplkCimTrackingAdmin_v2 as handler_splk_cim_admin,
-)
 from trackme_rest_handler_splk_flx_user import (
     TrackMeHandlerSplkFlxTrackingRead_v2 as handler_splk_flx_user,
 )
@@ -278,6 +270,14 @@ from trackme_rest_handler_component_power import (
     TrackMeHandlerComponentPower_v2 as handler_component_power,
 )
 
+from trackme_rest_handler_notes_user import (
+    TrackMeHandlerNotesRead_v2 as handler_notes_user,
+)
+
+from trackme_rest_handler_notes_power import (
+    TrackMeHandlerNotesWrite_v2 as handler_notes_power,
+)
+
 
 @Configuration(distributed=False)
 class TrackMeApiAutoDocs(GeneratingCommand):
@@ -381,9 +381,12 @@ class TrackMeApiAutoDocs(GeneratingCommand):
             handler_alerting_admin: {
                 "resource_group": "alerting/admin",
             },
-            handler_ack: {
+            handler_ack_user: {
                 "resource_group": "ack",
             },
+            handler_ack_power: {
+                "resource_group": "ack/write",
+            },            
             handler_audit: {
                 "resource_group": "audit",
             },
@@ -453,15 +456,6 @@ class TrackMeApiAutoDocs(GeneratingCommand):
             handler_splk_disruption_power: {
                 "resource_group": "splk_disruption/write",
             },
-            handler_splk_cim_user: {
-                "resource_group": "splk_cim",
-            },
-            handler_splk_cim_power: {
-                "resource_group": "splk_cim/write",
-            },
-            handler_splk_cim_admin: {
-                "resource_group": "splk_cim/admin",
-            },
             handler_splk_flx_user: {
                 "resource_group": "splk_flx",
             },
@@ -591,6 +585,12 @@ class TrackMeApiAutoDocs(GeneratingCommand):
             handler_component_power: {
                 "resource_group": "component/write",
             },
+            handler_notes_user: {
+                "resource_group": "notes",
+            },
+            handler_notes_power: {
+                "resource_group": "notes/write",
+            },
         }
 
         #
